==> lumina-1.1.0.tar.gz: lumina-1.1.0/src-qt5/core-utils/lumina-search/i18n/lumina-search_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>ConfigUI</name>
    <message>
        <location filename="../ConfigUI.ui" line="14"/>
        <source>Search Configuration</source>
        <translation>Søgekonfiguration</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="20"/>
        <source>Start Search:</source>
        <translation>Start søgning:</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="39"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="48"/>
        <source>Excluded Directories</source>
        <translation>Udeladte mapper</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="119"/>
        <source>Save as Defaults</source>
        <translation>Gem som standard</translation>
    </message>
    <message>
        <location filename="../ConfigUI.cpp" line="41"/>
        <source>Select Search Directory</source>
        <translation type="unfinished">Vælg søge mappe</translation>
    </message>
    <message>
        <location filename="../ConfigUI.cpp" line="54"/>
        <source>Exclude Directories</source>
        <translation>Udeladte mapper</translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <source>Search For...</source>
        <translation>Søg efter...</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="23"/>
        <source>Type to search</source>
        <translation>Skriv for at søge</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="30"/>
        <source>Configure search parameters</source>
        <translation>Indstil søge parametre</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="40"/>
        <source>Stop Active Search</source>
        <translation>Stop aktiv søgning</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="54"/>
        <source>Applications</source>
        <translation>Programmer</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="64"/>
        <source>Files or Directories</source>
        <translation>Filer og mapper</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="88"/>
        <source>Close</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="108"/>
        <source>Launch Item</source>
        <translation type="unfinished">Start enhed</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="119"/>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="122"/>
        <location filename="../MainUI.ui" line="125"/>
        <source>Save Screenshot</source>
        <translation>Gem skærmbillede</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="133"/>
        <location filename="../MainUI.ui" line="136"/>
        <source>Quit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="141"/>
        <source>Snap</source>
        <translation>Øjebliksbillede</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="144"/>
        <source>Take new snapshot</source>
        <translation>Tag nyt øjebliksbillede</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="29"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="95"/>
        <source>Search: %1 -- Smart: %2</source>
        <translation>Søg: %1 -- Smart: %2</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="98"/>
        <source>Off</source>
        <translation>Slukket</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="98"/>
        <source>On</source>
        <translation>Tændt</translation>
    </message>
</context>
<context>
    <name>Worker</name>
    <message>
        <location filename="../Worker.cpp" line="42"/>
        <source>Searching: %1</source>
        <translation>Søger: %1</translation>
    </message>
    <message>
        <location filename="../Worker.cpp" line="63"/>
        <source>Starting Search: %1</source>
        <translation>Starter søgning: %1</translation>
    </message>
    <message>
        <location filename="../Worker.cpp" line="111"/>
        <source>Search Finished</source>
        <translation>Søgning afsluttet</translation>
    </message>
</context>
</TS>

==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/core-utils/lumina-search/i18n/lumina-search_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>ConfigUI</name>
    <message>
        <location filename="../ConfigUI.ui" line="14"/>
        <source>Search Configuration</source>
        <translation>Søgekonfiguration</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="20"/>
        <source>Start Search:</source>
        <translation>Start søgning:</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="39"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="48"/>
        <source>Excluded Directories</source>
        <translation>Udeladte mapper</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="119"/>
        <source>Save as Defaults</source>
        <translation>Gem som standard</translation>
    </message>
    <message>
        <location filename="../ConfigUI.cpp" line="41"/>
        <source>Select Search Directory</source>
        <translation>Vælg søgemappe</translation>
    </message>
    <message>
        <location filename="../ConfigUI.cpp" line="54"/>
        <source>Exclude Directories</source>
        <translation>Udeladte mapper</translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <source>Search For...</source>
        <translation>Søg efter...</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="23"/>
        <source>Type to search</source>
        <translation>Skriv for at søge</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="30"/>
        <source>Configure search parameters</source>
        <translation>Indstil søge parametre</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="40"/>
        <source>Stop Active Search</source>
        <translation>Stop aktiv søgning</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="54"/>
        <source>Applications</source>
        <translation>Programmer</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="64"/>
        <source>Files or Directories</source>
        <translation>Filer og mapper</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="88"/>
        <source>Close</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="108"/>
        <source>Launch Item</source>
        <translation>Startenhed</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="119"/>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="122"/>
        <location filename="../MainUI.ui" line="125"/>
        <source>Save Screenshot</source>
        <translation>Gem skærmbillede</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="133"/>
        <location filename="../MainUI.ui" line="136"/>
        <source>Quit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="141"/>
        <source>Snap</source>
        <translation>Øjebliksbillede</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="144"/>
        <source>Take new snapshot</source>
        <translation>Tag nyt øjebliksbillede</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="29"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="96"/>
        <source>Search: %1 -- Smart: %2</source>
        <translation>Søg: %1 -- Smart: %2</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="99"/>
        <source>Off</source>
        <translation>Slukket</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="99"/>
        <source>On</source>
        <translation>Tændt</translation>
    </message>
</context>
<context>
    <name>Worker</name>
    <message>
        <location filename="../Worker.cpp" line="42"/>
        <source>Searching: %1</source>
        <translation>Søger: %1</translation>
    </message>
    <message>
        <location filename="../Worker.cpp" line="64"/>
        <source>Starting Search: %1</source>
        <translation>Starter søgning: %1</translation>
    </message>
    <message>
        <location filename="../Worker.cpp" line="112"/>
        <source>Search Finished</source>
        <translation>Søgning afsluttet</translation>
    </message>
</context>
</TS>
